@@ -1,4 +1,4 @@
-/* $ANTLR 2.7.7 (20120518): "format.g" -> "FMTLexer.cpp"$ */
+/* $ANTLR 2.7.7 (2006-11-01): "format.g" -> "FMTLexer.cpp"$ */
 
 #include "includefirst.hpp"
 
@@ -31,14 +31,8 @@ FMTLexer::FMTLexer(const antlr::LexerSharedInputState& state)
 
 void FMTLexer::initLiterals()
 {
-	literals["cyi"] = 64;
-	literals["csi"] = 66;
-	literals["cmi"] = 65;
-	literals["tl"] = 33;
-	literals["tr"] = 34;
-	literals["cdi"] = 63;
-	literals["cmoi"] = 62;
-	literals["csf"] = 67;
+	literals["tl"] = 39;
+	literals["tr"] = 40;
 }
 
 antlr::RefToken FMTLexer::nextToken()
@@ -115,19 +109,29 @@ antlr::RefToken FMTLexer::nextToken()
 				break;
 			}
 			case 0x45 /* 'E' */ :
-			case 0x65 /* 'e' */ :
 			{
 				mE(true);
 				theRetToken=_returnToken;
 				break;
 			}
+			case 0x65 /* 'e' */ :
+			{
+				mSE(true);
+				theRetToken=_returnToken;
+				break;
+			}
 			case 0x47 /* 'G' */ :
-			case 0x67 /* 'g' */ :
 			{
 				mG(true);
 				theRetToken=_returnToken;
 				break;
 			}
+			case 0x67 /* 'g' */ :
+			{
+				mSG(true);
+				theRetToken=_returnToken;
+				break;
+			}
 			case 0x49 /* 'I' */ :
 			case 0x69 /* 'i' */ :
 			{
@@ -216,72 +220,87 @@ antlr::RefToken FMTLexer::nextToken()
 				theRetToken=_returnToken;
 				break;
 			}
-			case 0x2b /* '+' */ :
-			case 0x2d /* '-' */ :
-			case 0x30 /* '0' */ :
-			case 0x31 /* '1' */ :
-			case 0x32 /* '2' */ :
-			case 0x33 /* '3' */ :
-			case 0x34 /* '4' */ :
-			case 0x35 /* '5' */ :
-			case 0x36 /* '6' */ :
-			case 0x37 /* '7' */ :
-			case 0x38 /* '8' */ :
-			case 0x39 /* '9' */ :
-			{
-				mNUMBER(true);
-				theRetToken=_returnToken;
-				break;
-			}
 			default:
-				if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x4d /* 'M' */ ) && (LA(3) == 0x4f /* 'O' */ )) {
+				if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x4d /* 'M' */ ) && (LA(3) == 0x4f /* 'O' */ ) && (LA(4) == 0x41 /* 'A' */ )) {
 					mCMOA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x4d /* 'M' */ ) && (LA(3) == 0x6f /* 'o' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x4d /* 'M' */ ) && (LA(3) == 0x4f /* 'O' */ ) && (LA(4) == 0x49 /* 'I' */ )) {
+					mCMOI(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x4d /* 'M' */ ) && (LA(3) == 0x6f /* 'o' */ )) {
 					mCMoA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x44 /* 'D' */ ) && (LA(3) == 0x57 /* 'W' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x44 /* 'D' */ ) && (LA(3) == 0x49 /* 'I' */ )) {
+					mCDI(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x4d /* 'M' */ ) && (LA(3) == 0x49 /* 'I' */ )) {
+					mCMI(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x53 /* 'S' */ ) && (LA(3) == 0x49 /* 'I' */ )) {
+					mCSI(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x53 /* 'S' */ ) && (LA(3) == 0x46 /* 'F' */ )) {
+					mCSF(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x44 /* 'D' */ ) && (LA(3) == 0x57 /* 'W' */ )) {
 					mCDWA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x44 /* 'D' */ ) && (LA(3) == 0x77 /* 'w' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x44 /* 'D' */ ) && (LA(3) == 0x77 /* 'w' */ )) {
 					mCDwA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x41 /* 'A' */ ) && (LA(3) == 0x50 /* 'P' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x41 /* 'A' */ ) && (LA(3) == 0x50 /* 'P' */ )) {
 					mCAPA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x41 /* 'A' */ ) && (LA(3) == 0x70 /* 'p' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x41 /* 'A' */ ) && (LA(3) == 0x70 /* 'p' */ )) {
 					mCApA(true);
 					theRetToken=_returnToken;
 				}
 				else if ((LA(1) == 0x25 /* '%' */ ) && (LA(2) == 0x22 /* '\"' */  || LA(2) == 0x27 /* '\'' */ )) {
-					mCSTRING(true);
+					mCSTYLE_STRING(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x6d /* 'm' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x6d /* 'm' */ )) {
 					mCmoA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x68 /* 'h' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x59 /* 'Y' */ )) {
+					mCYI(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x48 /* 'H' */ )) {
 					mCHI(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x48 /* 'H' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x68 /* 'h' */ )) {
 					mChI(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x64 /* 'd' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x64 /* 'd' */ )) {
 					mCdwA(true);
 					theRetToken=_returnToken;
 				}
-				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (LA(2) == 0x61 /* 'a' */ )) {
+				else if ((LA(1) == 0x43 /* 'C' */ ) && (LA(2) == 0x61 /* 'a' */ )) {
 					mCapA(true);
 					theRetToken=_returnToken;
 				}
+				else if ((LA(1) == 0x2b /* '+' */ ) && (LA(2) == 0x2d /* '-' */ )) {
+					mPM(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x2d /* '-' */ ) && (LA(2) == 0x2b /* '+' */ )) {
+					mMP(true);
+					theRetToken=_returnToken;
+				}
 				else if ((LA(1) == 0x43 /* 'C' */  || LA(1) == 0x63 /* 'c' */ ) && (true)) {
 					mC(true);
 					theRetToken=_returnToken;
@@ -290,14 +309,18 @@ antlr::RefToken FMTLexer::nextToken()
 					mPERCENT(true);
 					theRetToken=_returnToken;
 				}
-			else {
-				if (LA(1)==EOF_CHAR)
-				{
-					uponEOF();
-					_returnToken = makeToken(antlr::Token::EOF_TYPE);
+				else if ((LA(1) == 0x2b /* '+' */ ) && (true)) {
+					mPLUS(true);
+					theRetToken=_returnToken;
+				}
+				else if ((LA(1) == 0x2d /* '-' */ ) && (true)) {
+					mMOINS(true);
+					theRetToken=_returnToken;
+				}
+				else {
+					mNUMBER(true);
+					theRetToken=_returnToken;
 				}
-				else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
-			}
 			}
 			if ( !_returnToken )
 				goto tryAgain; // found SKIP token
@@ -345,11 +368,11 @@ void FMTLexer::mSTRING(bool _createToken) {
 				}
 			}
 			else {
-				goto _loop47;
+				goto _loop60;
 			}
 			
 		}
-		_loop47:;
+		_loop60:;
 		} // ( ... )*
 		_saveIndex = text.length();
 		match('\"' /* charlit */ );
@@ -375,11 +398,11 @@ void FMTLexer::mSTRING(bool _createToken) {
 				}
 			}
 			else {
-				goto _loop50;
+				goto _loop63;
 			}
 			
 		}
-		_loop50:;
+		_loop63:;
 		} // ( ... )*
 		_saveIndex = text.length();
 		match('\'' /* charlit */ );
@@ -399,9 +422,9 @@ void FMTLexer::mSTRING(bool _createToken) {
 	_saveIndex=0;
 }
 
-void FMTLexer::mCSTRING(bool _createToken) {
+void FMTLexer::mCSTYLE_STRING(bool _createToken) {
 	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
-	_ttype = CSTRING;
+	_ttype = CSTYLE_STRING;
 	std::string::size_type _saveIndex;
 	
 	if ((LA(1) == 0x25 /* '%' */ ) && (LA(2) == 0x22 /* '\"' */ )) {
@@ -617,22 +640,23 @@ void FMTLexer::mE(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	switch ( LA(1)) {
-	case 0x65 /* 'e' */ :
+	match('E' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mSE(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = SE;
+	std::string::size_type _saveIndex;
+	
 	{
-		match('e' /* charlit */ );
-		break;
-	}
-	case 0x45 /* 'E' */ :
-	{
-		match('E' /* charlit */ );
-		break;
-	}
-	default:
-	{
-		throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());
-	}
-	}
+	match('e' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -648,22 +672,23 @@ void FMTLexer::mG(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	switch ( LA(1)) {
-	case 0x67 /* 'g' */ :
+	match('G' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mSG(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = SG;
+	std::string::size_type _saveIndex;
+	
 	{
-		match('g' /* charlit */ );
-		break;
-	}
-	case 0x47 /* 'G' */ :
-	{
-		match('G' /* charlit */ );
-		break;
-	}
-	default:
-	{
-		throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());
-	}
-	}
+	match('g' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1021,10 +1046,10 @@ void FMTLexer::mCMOA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('M' /* charlit */ );
 	match('O' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1040,10 +1065,10 @@ void FMTLexer::mCMoA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('M' /* charlit */ );
 	match('o' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1059,10 +1084,119 @@ void FMTLexer::mCmoA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('m' /* charlit */ );
 	match('o' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mCMOI(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = CMOI;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('C' /* charlit */ );
+	match('M' /* charlit */ );
+	match('O' /* charlit */ );
+	match('I' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mCDI(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = CDI;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('C' /* charlit */ );
+	match('D' /* charlit */ );
+	match('I' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mCMI(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = CMI;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('C' /* charlit */ );
+	match('M' /* charlit */ );
+	match('I' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mCYI(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = CYI;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('C' /* charlit */ );
+	match('Y' /* charlit */ );
+	match('I' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mCSI(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = CSI;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('C' /* charlit */ );
+	match('S' /* charlit */ );
+	match('I' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mCSF(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = CSF;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('C' /* charlit */ );
+	match('S' /* charlit */ );
+	match('F' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1078,9 +1212,9 @@ void FMTLexer::mCHI(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
-	match('h' /* charlit */ );
-	mI(false);
+	match('C' /* charlit */ );
+	match('H' /* charlit */ );
+	match('I' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1096,9 +1230,9 @@ void FMTLexer::mChI(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
-	match('H' /* charlit */ );
-	mI(false);
+	match('C' /* charlit */ );
+	match('h' /* charlit */ );
+	match('I' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1114,10 +1248,10 @@ void FMTLexer::mCDWA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('D' /* charlit */ );
 	match('W' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1133,10 +1267,10 @@ void FMTLexer::mCDwA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('D' /* charlit */ );
 	match('w' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1152,10 +1286,10 @@ void FMTLexer::mCdwA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('d' /* charlit */ );
 	match('w' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1171,10 +1305,10 @@ void FMTLexer::mCAPA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('A' /* charlit */ );
 	match('P' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1190,10 +1324,10 @@ void FMTLexer::mCApA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('A' /* charlit */ );
 	match('p' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1209,10 +1343,10 @@ void FMTLexer::mCapA(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{
-	mC(false);
+	match('C' /* charlit */ );
 	match('a' /* charlit */ );
 	match('p' /* charlit */ );
-	mA(false);
+	match('A' /* charlit */ );
 	}
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1250,6 +1384,68 @@ void FMTLexer::mDOT(bool _createToken) {
 	_saveIndex=0;
 }
 
+void FMTLexer::mPM(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = PM;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('+' /* charlit */ );
+	match('-' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mMP(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = MP;
+	std::string::size_type _saveIndex;
+	
+	{
+	match('-' /* charlit */ );
+	match('+' /* charlit */ );
+	}
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mPLUS(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = PLUS;
+	std::string::size_type _saveIndex;
+	
+	match('+' /* charlit */ );
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
+void FMTLexer::mMOINS(bool _createToken) {
+	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
+	_ttype = MOINS;
+	std::string::size_type _saveIndex;
+	
+	match('-' /* charlit */ );
+	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
+	   _token = makeToken(_ttype);
+	   _token->setText(text.substr(_begin, text.length()-_begin));
+	}
+	_returnToken = _token;
+	_saveIndex=0;
+}
+
 void FMTLexer::mW(bool _createToken) {
 	int _ttype; antlr::RefToken _token; std::string::size_type _begin = text.length();
 	_ttype = W;
@@ -1287,18 +1483,18 @@ void FMTLexer::mWHITESPACE(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{ // ( ... )+
-	int _cnt120=0;
+	int _cnt155=0;
 	for (;;) {
 		if ((LA(1) == 0x9 /* '\t' */  || LA(1) == 0x20 /* ' ' */ )) {
 			mW(false);
 		}
 		else {
-			if ( _cnt120>=1 ) { goto _loop120; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
+			if ( _cnt155>=1 ) { goto _loop155; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
 		}
 		
-		_cnt120++;
+		_cnt155++;
 	}
-	_loop120:;
+	_loop155:;
 	}  // ( ... )+
 	_ttype=antlr::Token::SKIP;
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
@@ -1315,18 +1511,18 @@ void FMTLexer::mDIGITS(bool _createToken) {
 	std::string::size_type _saveIndex;
 	
 	{ // ( ... )+
-	int _cnt123=0;
+	int _cnt158=0;
 	for (;;) {
 		if (((LA(1) >= 0x30 /* '0' */  && LA(1) <= 0x39 /* '9' */ ))) {
 			matchRange('0','9');
 		}
 		else {
-			if ( _cnt123>=1 ) { goto _loop123; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
+			if ( _cnt158>=1 ) { goto _loop158; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
 		}
 		
-		_cnt123++;
+		_cnt158++;
 	}
-	_loop123:;
+	_loop158:;
 	}  // ( ... )+
 	if ( _createToken && _token==antlr::nullToken && _ttype!=antlr::Token::SKIP ) {
 	   _token = makeToken(_ttype);
@@ -1358,85 +1554,49 @@ void FMTLexer::mNUMBER(bool _createToken) {
 	std::string::size_type _saveIndex;
 	antlr::RefToken num;
 	
-	SizeT n;
+	SizeT n = -1;
 	SizeT i = 0;
-	bool uPlus = false;
-	bool uMinus = false;
 	
 	
 	{
-	switch ( LA(1)) {
-	case 0x2d /* '-' */ :
-	{
-		match('-' /* charlit */ );
-		
-		uMinus = true;
-		
-		break;
-	}
-	case 0x2b /* '+' */ :
-	{
-		match('+' /* charlit */ );
-		
-		uPlus = true;
-		
-		break;
-	}
-	case 0x30 /* '0' */ :
-	case 0x31 /* '1' */ :
-	case 0x32 /* '2' */ :
-	case 0x33 /* '3' */ :
-	case 0x34 /* '4' */ :
-	case 0x35 /* '5' */ :
-	case 0x36 /* '6' */ :
-	case 0x37 /* '7' */ :
-	case 0x38 /* '8' */ :
-	case 0x39 /* '9' */ :
-	{
-		break;
-	}
-	default:
-	{
-		throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());
-	}
-	}
-	}
-	mDIGITS(true);
-	num=_returnToken;
-	
-	if( uMinus) num->setText( "-" + num->getText());
-	if( uPlus) num->setText( "+" + num->getText());
-	
-	{
-	if ((LA(1) == 0x48 /* 'H' */ )) {
-		
-		_ttype = STRING; 
-		std::istringstream s(num->getText());
-		s >> n;
-		{ text.erase(_begin); text += ""; }; // clear string (remove number)
-		
-		_saveIndex = text.length();
-		match('H' /* charlit */ );
-		text.erase(_saveIndex);
-		{ // ( ... )+
-		int _cnt130=0;
-		for (;;) {
-			// init action gets executed even in guessing mode
-			if( i == n )
-			break;
-			i++; // count chars here so that guessing mode works
+	if (((LA(1) >= 0x30 /* '0' */  && LA(1) <= 0x39 /* '9' */ ))) {
+		mDIGITS(true);
+		num=_returnToken;
+		{
+		if ((LA(1) == 0x48 /* 'H' */  || LA(1) == 0x68 /* 'h' */ )) {
 			
-			if (((LA(1) >= 0x3 /* '\3' */  && LA(1) <= 0xff))) {
-				mCHAR(false);
-			}
-			else {
-				if ( _cnt130>=1 ) { goto _loop130; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
-			}
+			_ttype = STRING; 
+			std::istringstream s(num->getText());
+			s >> n;
+			{ text.erase(_begin); text += ""; }; // clear string (remove number)
 			
-			_cnt130++;
+			_saveIndex = text.length();
+			mH(false);
+			text.erase(_saveIndex);
+			{ // ( ... )+
+			int _cnt165=0;
+			for (;;) {
+				// init action gets executed even in guessing mode
+				if( i == n )
+				break;
+				i++; // count chars here so that guessing mode works
+				
+				if (((LA(1) >= 0x3 /* '\3' */  && LA(1) <= 0xff))) {
+					mCHAR(false);
+				}
+				else {
+					if ( _cnt165>=1 ) { goto _loop165; } else {throw antlr::NoViableAltForCharException(LA(1), getFilename(), getLine(), getColumn());}
+				}
+				
+				_cnt165++;
+			}
+			_loop165:;
+			}  // ( ... )+
+		}
+		else {
+		}
+		
 		}
-		_loop130:;
-		}  // ( ... )+
 	}
 	else {
 	}
@@ -1455,12 +1615,12 @@ const unsigned long FMTLexer::_tokenSet_0_data_[] = { 4294967288UL, 4294967291UL
 // 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xa 0xb 0xc 0xd 0xe 0xf 0x10 0x11 0x12 0x13 
 // 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f   ! # $ 
 // % & \' ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B C D E F 
-// G H I J K L M 
+// G H I J K L M N O P Q R S T U V 
 const antlr::BitSet FMTLexer::_tokenSet_0(_tokenSet_0_data_,16);
 const unsigned long FMTLexer::_tokenSet_1_data_[] = { 4294967288UL, 4294967167UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 4294967295UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL, 0UL };
 // 0x3 0x4 0x5 0x6 0x7 0x8 0x9 0xa 0xb 0xc 0xd 0xe 0xf 0x10 0x11 0x12 0x13 
 // 0x14 0x15 0x16 0x17 0x18 0x19 0x1a 0x1b 0x1c 0x1d 0x1e 0x1f   ! \" # 
 // $ % & ( ) * + , - . / 0 1 2 3 4 5 6 7 8 9 : ; < = > ? @ A B C D E F 
-// G H I J K L M 
+// G H I J K L M N O P Q R S T U V 
 const antlr::BitSet FMTLexer::_tokenSet_1(_tokenSet_1_data_,16);
 
